@@ -118,17 +118,19 @@ class FileMultiEntityFactory(object):
         store_name = self._sanitise(store_name)
         new_name = self._sanitise(new_name)
         pass
-    
+
+    def list_ids(self, store):
+        store = self._sanitise(store)
+        if self.status.get(store, False) and store in self.stores:
+            return self.stores[store].list_ids()
+
     def get(self, uri):
         pass
     
     def get_id(self, id, store):
-        store_name = self._sanitise(store)
-        if not store_name in self.stores:
-            raise NotAValidStoreName()
-        else:
-            return self.stores[store_name].get_id(id)
-    
+        store = self._sanitise(store)
+        if self.status.get(store, False) and store in self.stores:
+            return self.stores[store].get_id(id)
 
 class FileEntityFactory(object):
     def __init__(self, uri_base=URI_BASE, storage_dir=STORAGE_DIR, 
@@ -161,4 +163,7 @@ class FileEntityFactory(object):
     def delete(self, uri):
         if uri.startswith(self.uri_base):
             id = uri[len(self.uri_base):]
-        
+
+    def list_ids(self):
+        """ EXPENSIVE - involves crawling the entire store pairtree directory"""
+        return self._s.list_ids()
