@@ -78,8 +78,8 @@ class FileStorageObject(object):
         """RDFObject for this object"""
         return self.fs._get_rdfobject(self.id, u'ROOT')
 
-    def add_part(self, partid, bytestream, buffer_size):
-        return self.fs._put_part(self.id, partid, bytestream, buffer_size)
+    def add_part(self, partid, bytestream):
+        return self.fs._put_part(self.id, partid, bytestream)
 
     def get_part(self, partid, stream=False):
         return self.fs._get_part(self.id, partid, stream)
@@ -169,16 +169,23 @@ class FileStorageClient(object):
 
         if not os.path.isdir(self.store_dir):
             raise NotAPairtreeStoreException
+
+    def list_ids(self):
         # load existing objects from the peartree
-#        for dirpath, dirnames, filenames in os.walk(self.store_dir):
-#            leaf = False
-#            for filename in [x for x in filenames if not x.startswith('pairtree')]:
-#                if len(filename) > self.shorty_length:
-#                    leaf = True
-#            if leaf:
-#                this_id = self._get_id_from_dirpath(dirpath)
-#                self.ids[this_id] = dirpath
-#                self.id_parts[this_id] = dirnames
+        objects = []
+        for dirpath, dirnames, filenames in os.walk(self.store_dir):
+            leaf = False
+            dir_contents = dirnames + filenames
+            for name in [x for x in dir_contents if not x.startswith('pairtree')]:
+                if len(name) > self.shorty_length:
+                    leaf = True
+            if leaf:
+                objects.append(self._get_id_from_dirpath(dirpath))
+                # # Much more detailed info than was needed
+                #this_id = self._get_id_from_dirpath(dirpath)
+                #self.ids[this_id] = dirpath
+                #self.id_parts[this_id] = dirnames
+        return objects
 
     def _create(self, id):
         dirpath = self._id_to_dirpath(id)
@@ -221,7 +228,7 @@ class FileStorageClient(object):
         f.close()
         return version_no
 
-    def _put_part(self, id, part_id, bytestream, buffer_size):
+    def _put_part(self, id, part_id, bytestream):
         dirpath = os.path.join(self._id_to_dirpath(id), "%s" % (part_id))
         if not os.path.exists(dirpath):
             os.mkdir(dirpath)
@@ -231,8 +238,7 @@ class FileStorageClient(object):
         try:
             # Stream file-like objects in with buffered reads
             if hasattr(bytestream, 'read'):
-                if not buffer_size or buffer_size<1024:
-                    buffer_size = 1024 * 8
+                buffer_size = 1024 * 8
                 chunk = bytestream.read(buffer_size)
                 while chunk:
                     f.write(chunk)
